<?php

/*
 * Miscellaneous helpers for dojox.gfx
 *
 */


/*
 * dojo_toolkit_svggfx
 *
 * Modeled on Imagecache, we transform an SVG file to a Dojox.gfx file
 * and store in the file directory
 *
 * This is a menu callback, and expects to find an svg file to transform.
 * It writes out a .json file with the same name.
 */
function dojo_toolkit_svggfx() {
  $args = func_get_args();
  $src = $path = implode('/', $args);
  // Source path is .svg, destination path is .json
  $src = dirname($src) . '/' . basename($src, '.json') . '.svg';
  
  // Check if the path to the file exists.
  if (!is_file($src) && !is_file($src = file_create_path($src))) {
    watchdog('dojox.gfx', '404: Unable to find %image ', array('%image' => $src), WATCHDOG_ERROR);
    header("HTTP/1.0 404 Not Found");
    exit;
  };
  
  $dst = file_create_path().'/svggfx/' . $path;
  $dir = dirname($dst);
  
  // Build the destination folder tree if it doesn't already exists.
  if (!file_check_directory($dir, FILE_CREATE_DIRECTORY) && !mkdir($dir, 0775, TRUE)) {
    watchdog('imagecache', 'Failed to create imagecache directory: %dir', array('%dir' => $dir), WATCHDOG_ERROR);
    return FALSE;
  }
  
  //$dst = $dir . '/' . basename($dst,'.svg') . '.json';
  $dojojs = variable_get('dojo_toolkit_js',DOJO_TOOLKIT_VERSION);
  $dojopath = dirname(dirname($dojojs)); // go up one directory from dojo.js file
  
  $transform = $dojopath . '/dojox/gfx/resources/svg2gfx.xsl';
  $result = `xsltproc $transform "$src" | sed -e 's/,\([]}]\)/\\1/g' > "$dst"`;
  // now remove trailing commas that mess up IE...
  
  
  $headers = array('Content-Type: text/json');
  if ($fileinfo = stat($dst)) {
    $headers[] = 'Content-Length: '. $fileinfo[7];
    $headers[] = 'Expires: ' . gmdate('D, d M Y H:i:s', time() + 1209600) .' GMT';
    $headers[] = 'Cache-Control: max-age=1209600, private, must-revalidate';
    _imagecache_cache_set_cache_headers($fileinfo, $headers);
  }
  
  file_transfer($dst, $headers);
  exit;
}

